package com.jiuqi.grid;

/* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/TextCellProperty.class */
public class TextCellProperty implements TextCellPropertyIntf, CellDataProcessorIntf {
    protected CellDataPropertyIntf cellDataProperty;

    public TextCellProperty(GridCell cell) {
        this(new CellDataProperty(cell));
    }

    public TextCellProperty(CellDataPropertyIntf dataProperty) {
        this.cellDataProperty = dataProperty;
    }

    public CellDataPropertyIntf getCellDataProperty() {
        return this.cellDataProperty;
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public boolean getMultiLine() {
        return (this.cellDataProperty.getDataFlag() & 1) != 0;
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public void setMultiLine(boolean value) {
        if (value) {
            this.cellDataProperty.setDataFlag((byte) (this.cellDataProperty.getDataFlag() | 1));
        } else {
            this.cellDataProperty.setDataFlag((byte) (this.cellDataProperty.getDataFlag() & (-2)));
        }
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public boolean getAllowMultiLine() {
        return (this.cellDataProperty.getDataFlag() & 2) != 0;
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public void setAllowMultiLine(boolean value) {
        if (value) {
            this.cellDataProperty.setDataFlag((byte) (this.cellDataProperty.getDataFlag() | 2));
        } else {
            this.cellDataProperty.setDataFlag((byte) (this.cellDataProperty.getDataFlag() & (-3)));
        }
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public int getCharCase() {
        return this.cellDataProperty.getDataFlag() >> 2;
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public void setCharCase(int value) {
        if (value >= 0 && value < 3) {
            int data = (value & 3) << 2;
            this.cellDataProperty.setDataFlag((byte) ((this.cellDataProperty.getDataFlag() & (-13)) | data));
            return;
        }
        throw new IllegalArgumentException("错误设置了文本大小写情况,只能在0-2之间！");
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public int getMaxLength() {
        return this.cellDataProperty.getDataProperty();
    }

    @Override // com.jiuqi.grid.TextCellPropertyIntf
    public void setMaxLength(int value) {
        if (value >= 0) {
            this.cellDataProperty.setDataProPerty((short) value);
            return;
        }
        throw new IllegalArgumentException("不能设置文本的最大长度为负数！");
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String getEditText(String storeText) {
        return storeText;
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String getShowText(String storeText) {
        return storeText;
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String parseEditText(String editText) {
        String storeText;
        if (editText != null) {
            if (editText == "") {
                return "";
            }
            int charCase = getCharCase();
            switch (charCase) {
                case 0:
                    storeText = editText;
                    break;
                case 1:
                    storeText = editText.toUpperCase();
                    break;
                case 2:
                    storeText = editText.toLowerCase();
                    break;
                default:
                    storeText = editText;
                    break;
            }
            int textLength = storeText.length();
            int maxLength = getMaxLength();
            if (maxLength != 0 && textLength > maxLength) {
                storeText = storeText.substring(0, maxLength);
            }
            return storeText;
        }
        throw new IllegalArgumentException("不能解析指向null的字符串！");
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String parseShowText(String showText) {
        return parseEditText(showText);
    }
}
