package com.jiuqi.monitor;

/* loaded from: com_jiuqi_monitor.jar:com/jiuqi/monitor/ProgressTask.class */
final class ProgressTask {
    private String name;
    private int stepCount;
    private int[] steps;
    private int curStep;
    private double start;
    private double total;

    public ProgressTask(ProgressTask parent, String name, int stepCount) {
        this(parent, name, stepCount, null);
    }

    public ProgressTask(ProgressTask parent, String name, int[] steps) {
        this(parent, name, steps.length, steps);
    }

    private ProgressTask(ProgressTask parent, String name, int stepCount, int[] steps) {
        this.name = name;
        this.stepCount = stepCount;
        this.steps = steps;
        this.curStep = 0;
        if (parent == null) {
            this.start = 0.0d;
            this.total = 1.0d;
        } else {
            this.start = parent.position();
            this.total = parent.total() * parent.currentRate();
        }
    }

    public String name() {
        return this.name;
    }

    public void stepIn() {
        if (this.curStep < this.stepCount) {
            this.curStep++;
        }
    }

    public double total() {
        return this.total;
    }

    public double position() {
        if (this.steps == null) {
            return this.start + ((this.curStep / this.stepCount) * this.total);
        }
        int all = 0;
        for (int i = 0; i < this.stepCount; i++) {
            all += this.steps[i];
        }
        int established = 0;
        for (int i2 = 0; i2 < this.curStep; i2++) {
            established += this.steps[i2];
        }
        return this.start + ((established / all) * this.total);
    }

    public double currentRate() {
        if (this.steps == null) {
            return 1.0d / this.stepCount;
        }
        int all = 0;
        for (int i = 0; i < this.stepCount; i++) {
            all += this.steps[i];
        }
        return this.steps[this.curStep] / all;
    }
}
