package com.jiuqi.script;

/* loaded from: com_jiuqi_script.jar:com/jiuqi/script/ScriptException.class */
public class ScriptException extends Exception {
    private String sourceName;
    private int lineNumber;
    private int columnNumber;

    public ScriptException() {
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
    }

    public ScriptException(Throwable cause) {
        super(cause);
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
    }

    public ScriptException(String message) {
        super(message);
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
    }

    public ScriptException(String message, Throwable cause) {
        super(message, cause);
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
    }

    public ScriptException(String message, String sourceName, int lineNumber, int columnNumber) {
        super(message);
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
        this.sourceName = sourceName;
        this.columnNumber = columnNumber;
        this.lineNumber = lineNumber;
    }

    public ScriptException(String message, String sourceName, int lineNumber, int columnNumber, Throwable cause) {
        super(message, cause);
        this.sourceName = null;
        this.lineNumber = -1;
        this.columnNumber = -1;
        this.sourceName = sourceName;
        this.columnNumber = columnNumber;
        this.lineNumber = lineNumber;
    }

    public String getSourceName() {
        return this.sourceName;
    }

    public int getLineNumber() {
        return this.lineNumber;
    }

    public int getColumnNumber() {
        return this.columnNumber;
    }

    @Override // java.lang.Throwable
    public String getMessage() {
        String ret = super.getMessage();
        if (this.sourceName != null) {
            ret = String.valueOf(ret) + " in " + this.sourceName;
            if (this.lineNumber != -1) {
                ret = String.valueOf(ret) + " at line number " + this.lineNumber;
            }
            if (this.columnNumber != -1) {
                ret = String.valueOf(ret) + " at column number " + this.columnNumber;
            }
        }
        return ret;
    }
}
