package com.jiuqi.sql.impl;

import com.jiuqi.sql.DBException;
import com.jiuqi.sql.FieldInfo;
import com.jiuqi.sql.FieldInfoList;
import com.jiuqi.sql.OutputDataSet;
import com.jiuqi.sql.OutputRecordBuffer;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;

/* loaded from: com_jiuqi_sql_impl.jar:com/jiuqi/sql/impl/DBaseOutputDataSet.class */
public class DBaseOutputDataSet extends OutputDataSet {
    private DBaseOutputRecordBuffer buffer;
    private FieldInfoList infoList;
    private long recordCount;
    private DBaseFileHeader header = new DBaseFileHeader();
    private DBaseFileTail tail = new DBaseFileTail();
    private OutputStream stream = new ByteArrayOutputStream();

    public byte[] getBytes() {
        return ((ByteArrayOutputStream) this.stream).toByteArray();
    }

    public OutputStream getStream() {
        return this.stream;
    }

    protected OutputRecordBuffer internalOpen() throws DBException {
        return this.buffer;
    }

    private void writeRecCountToStream() throws IOException {
        this.header.recCount = this.recordCount;
        ByteArrayOutputStream byteStream = (ByteArrayOutputStream) this.stream;
        byte[] copyData = byteStream.toByteArray();
        byte[] recCountBefore = new byte[4];
        int afterLength = copyData.length - 8;
        byte[] recCountAfter = new byte[afterLength];
        System.arraycopy(copyData, 0, recCountBefore, 0, 4);
        System.arraycopy(copyData, 8, recCountAfter, 0, afterLength);
        byteStream.reset();
        byteStream.write(recCountBefore);
        RW.writeDWord(byteStream, this.recordCount);
        byteStream.write(recCountAfter);
    }

    protected void internalClose() throws DBException {
        try {
            writeRecCountToStream();
            if (this.tail.size() > 0) {
                this.stream.write(26);
                this.tail.writeToStream(this.stream);
            }
            this.stream.write(26);
            this.buffer = null;
        } catch (Exception ex) {
            throw new DBException(ex.getMessage());
        }
    }

    protected void postRecord(OutputRecordBuffer buffer) throws DBException {
        this.recordCount++;
        buffer.writeRecord(this.stream);
    }

    protected void internalCreate(FieldInfoList fieldInfos) throws DBException {
        this.infoList = fieldInfos;
        int fieldCount = this.infoList.size();
        if (fieldCount == 0) {
            throw new DBException("没有定义字段信息！");
        }
        int fieldOffset = 0;
        for (int i = 0; i < fieldCount; i++) {
            try {
                FieldInfo fieldInfo = this.infoList.get(i);
                fieldInfo.offset = fieldOffset;
                if (fieldInfo.type == 6) {
                    fieldOffset += 4;
                } else {
                    fieldOffset += fieldInfo.size;
                }
            } catch (IOException ex) {
                throw new DBException(ex);
            }
        }
        this.header.recLength = fieldOffset + 1;
        this.header.structDefLen = 68 + (fieldCount * 50) + 1;
        this.header.beginCreateFile();
        this.header.writeToStream(this.stream);
        DBaseFieldHeader fieldHeader = new DBaseFieldHeader();
        for (int i2 = 0; i2 < fieldCount; i2++) {
            FieldInfo fieldInfo2 = this.infoList.get(i2);
            fieldHeader.fieldName = fieldInfo2.name;
            fieldHeader.incValue = fieldInfo2.incValue;
            fieldHeader.fieldLength = fieldInfo2.size;
            fieldHeader.scale = (byte) fieldInfo2.decimal;
            fieldHeader.setDataType(fieldInfo2.type);
            fieldHeader.writeToStream(this.stream);
        }
        this.stream.write(13);
        this.buffer = new DBaseOutputRecordBuffer(this.header.recLength - 1, this.tail);
    }
}
