package com.jiuqi.util;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/ByteFunc.class */
public class ByteFunc {
    private ByteFunc() {
    }

    public static short readShort(byte[] data, int pos) {
        int b1 = data[pos] & 255;
        int b2 = data[pos + 1] & 255;
        return (short) ((b2 << 8) + (b1 << 0));
    }

    public static int readWord(byte[] data, int pos) {
        int b1 = data[pos] & 255;
        int b2 = data[pos + 1] & 255;
        return (b2 << 8) + (b1 << 0);
    }

    public static int readInt(byte[] data, int pos) {
        int b1 = data[pos] & 255;
        int b2 = data[pos + 1] & 255;
        int b3 = data[pos + 2] & 255;
        int b4 = data[pos + 3] & 255;
        return (b4 << 24) + (b3 << 16) + (b2 << 8) + (b1 << 0);
    }

    public static float readFloat(byte[] data, int pos) {
        return Float.intBitsToFloat(readInt(data, pos));
    }

    public static double readDouble(byte[] data, int pos) {
        return Double.longBitsToDouble(readLong(data, pos));
    }

    public static String readString(byte[] data, int pos, int length) {
        byte[] str = new byte[length];
        for (int i = pos; i < pos + length; i++) {
            str[i] = data[i];
        }
        return new String(str);
    }

    public static boolean readBool(byte[] data, int pos) {
        return data[pos] > 0;
    }

    public static long readLong(byte[] data, int pos) {
        long b1 = data[pos] & 255;
        long b2 = data[pos + 1] & 255;
        long b3 = data[pos + 2] & 255;
        long b4 = data[pos + 3] & 255;
        long b5 = data[pos + 4] & 255;
        long b6 = data[pos + 5] & 255;
        long b7 = data[pos + 6] & 255;
        long b8 = data[pos + 7];
        return (b8 << 56) + (b7 << 48) + (b6 << 40) + (b5 << 32) + (b4 << 24) + (b3 << 16) + (b2 << 8) + (b1 << 0);
    }

    public static void writeShort(byte[] data, int pos, short value) {
        data[pos] = (byte) ((value >>> 0) & 255);
        data[pos + 1] = (byte) ((value >>> 8) & 255);
    }

    public static void writeWord(byte[] data, int pos, int value) {
        data[pos] = (byte) ((value >>> 0) & 255);
        data[pos + 1] = (byte) ((value >>> 8) & 255);
    }

    public static void writeInt(byte[] data, int pos, int value) {
        data[pos] = (byte) ((value >>> 0) & 255);
        data[pos + 1] = (byte) ((value >>> 8) & 255);
        data[pos + 2] = (byte) ((value >>> 16) & 255);
        data[pos + 3] = (byte) ((value >>> 24) & 255);
    }

    public static void writeLong(byte[] data, int pos, long value) {
        data[pos] = (byte) ((value >>> 0) & 255);
        data[pos + 1] = (byte) ((value >>> 8) & 255);
        data[pos + 2] = (byte) ((value >>> 16) & 255);
        data[pos + 3] = (byte) ((value >>> 24) & 255);
        data[pos + 4] = (byte) ((value >>> 32) & 255);
        data[pos + 5] = (byte) ((value >>> 40) & 255);
        data[pos + 6] = (byte) ((value >>> 48) & 255);
        data[pos + 7] = (byte) ((value >>> 56) & 255);
    }

    public static void writeFloat(byte[] data, int pos, float value) {
        writeInt(data, pos, Float.floatToIntBits(value));
    }

    public static void writeDouble(byte[] data, int pos, double value) {
        writeLong(data, pos, Double.doubleToLongBits(value));
    }

    public static void writeBool(byte[] data, int pos, boolean value) {
        data[pos] = value ? (byte) 1 : (byte) 0;
    }

    public static void writeString(byte[] data, int pos, int length, String value) {
        byte[] b = value.getBytes();
        for (int i = pos; i < pos + length; i++) {
            if (b != null && 0 < b.length) {
                data[i] = b[0];
            } else {
                data[i] = 0;
            }
        }
    }
}
