package com.jiuqi.util.chinese;

/* loaded from: com_jiuqi_util_chinese.jar:com/jiuqi/util/chinese/StringSplitor.class */
public class StringSplitor {
    private final char[] CHARS;
    private int position;
    private int nextPosition;
    private final char[] EXCLUDE_SET;

    public StringSplitor(String value, char[] excludSet) {
        if (value != null) {
            this.CHARS = value.toCharArray();
            this.position = -1;
            this.nextPosition = -1;
            this.EXCLUDE_SET = excludSet;
            return;
        }
        throw new IllegalArgumentException("指向空的字符串指针！");
    }

    public boolean isValidChar(char theChar) {
        boolean found = false;
        int i = 0;
        while (true) {
            if (i >= this.EXCLUDE_SET.length) {
                break;
            }
            if (this.EXCLUDE_SET[i] != theChar) {
                i++;
            } else {
                found = true;
                break;
            }
        }
        return !found;
    }

    public boolean hasValidChar() {
        if (this.position == this.CHARS.length - 1) {
            return false;
        }
        if (this.nextPosition > this.position) {
            return true;
        }
        for (int i = this.position + 1; i < this.CHARS.length; i++) {
            char thisChar = this.CHARS[i];
            if (isValidChar(thisChar)) {
                this.nextPosition = i;
                return true;
            }
        }
        return false;
    }

    public char getNextValidChar() throws NoValidCharException {
        if (hasValidChar()) {
            this.position = this.nextPosition;
            return this.CHARS[this.position];
        }
        throw new NoValidCharException("这个字符串已经没有非空格的字符！");
    }

    public void rollBack() {
        boolean found = false;
        int prePosition = this.position - 1;
        while (true) {
            if (prePosition < 0) {
                break;
            }
            if (!isValidChar(this.CHARS[prePosition])) {
                prePosition--;
            } else {
                found = true;
                break;
            }
        }
        if (found) {
            this.position = prePosition;
        } else {
            this.position = -1;
        }
        this.nextPosition = this.position;
    }

    public String getLeft() {
        return new String(this.CHARS, this.position + 1, (this.CHARS.length - this.position) - 1);
    }

    public int validLength() {
        int length = 0;
        for (int i = 0; i < this.CHARS.length; i++) {
            if (isValidChar(this.CHARS[i])) {
                length++;
            }
        }
        return length;
    }
}
